@@ -25,12 +25,18 @@ sub build_binaries {
     ### DEVEL BUILD ###
     @imtargets  = qw[im im_process im_jp2 im_fftw]; #xxx im_capture removed
     @cdtargets  = qw[cd_zlib cd_freetype cd_ftgl cd cd_pdflib cdpdf cdgl]; #xxx add cdcontextplus
-    @iuptargets = qw[iup iupcd iupcontrols iup_pplot iup_mglplot iupgl iupim iupimglib iupole iupweb iuptuio];
+    @iuptargets = qw[iup iupcd iupcontrols iup_pplot iup_mglplot iupgl iupglcontrols iup_scintilla iupim iupimglib iupole iupweb iuptuio];
   }
   else {
     @imtargets  = qw[im];
     @cdtargets  = qw[cd_zlib cd_freetype cd];
-    @iuptargets = qw[iup iupcd iupcontrols iup_pplot iup_mglplot iupgl iupim iupimglib iupole];
+    @iuptargets = qw[iup iupcd iupcontrols iup_pplot iup_mglplot iupgl iupglcontrols iup_scintilla iupim iupimglib iupole];
+  }
+  
+  #iup_mglplot will not compile with too old cygwin (approx. detection via gcc version)
+  if ($Config{gccversion} =~ /^3\./) {
+    warn "###WARN### disabling iup_mglplot (fails to compile with gcc3\n";
+    @iuptargets = grep { $_ !~ /^(iup_mglplot)$/ } @iuptargets;
   }
 
   #make options
@@ -73,7 +79,7 @@ sub build_binaries {
   $self->config_data('iup_libs', {map {$_=>1} @iuplibs} );
   $self->config_data('linker_libs', [ @iuplibs, qw/gdi32 comdlg32 comctl32 winspool uuid ole32 oleaut32 opengl32 glu32/ ] );
   $self->config_data('extra_cflags', '');
-  $self->config_data('extra_lflags', '');
+  $self->config_data('extra_lflags', '-L/usr/lib/w32api');
 
   print STDERR "Build finished!\n";
   return $success;
